@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -32,8 +32,8 @@ class MarkUnoptimizedFunctionIndicatorMixin(object):
     """
 
     def __init__(self, flags):
-        self.unoptimized_locals = "has_exec" in flags
-        self.unqualified_exec = "has_unqualified_exec" in flags
+        self.unoptimized_locals = flags is not None and "has_exec" in flags
+        self.unqualified_exec = flags is not None and "has_unqualified_exec" in flags
 
     def isUnoptimized(self):
         return self.unoptimized_locals
@@ -41,9 +41,6 @@ class MarkUnoptimizedFunctionIndicatorMixin(object):
     def isUnqualifiedExec(self):
         return self.unoptimized_locals and self.unqualified_exec
 
-    def getLocalsScope(self):
-        return self.locals_scope
-
 
 class MarkNeedsAnnotationsMixin(object):
     def __init__(self):
